@@ -1,6 +1,6 @@
 from urllib.parse import urlparse
 
-from mext import enums, exceptions, providers
+from mext import enums, exceptions, providers, client
 
 slots = tuple(enums.DatacallAttributes.values())
 
@@ -31,8 +31,8 @@ class Mext:
 
         if wrong_types:
             raise ValueError(
-                "Wrong fetch types provided: {}. Valid fetch types are: {}".format(
-                    wrong_types, valid_fetch_types)
+                "Wrong fetch types provided: {}. Valid fetch types are: {}"\
+                    .format(wrong_types, valid_fetch_types)
             )
 
         return type_list
@@ -58,4 +58,4 @@ class Mext:
         for key, value in data.items():
             setattr(self, key, value)
 
-        return self
+        return self
\ No newline at end of file
